==> manpages-l10n_4.14.0.orig.tar.gz: manpages-l10n-4.14.0/README.md <==
# manpages-l10n

This project provides an infrastructure for translating manpages to different
languages. Currently we support the following languages:

*  cs - [Czech](https://salsa.debian.org/manpages-l10n-team/manpages-l10n/-/tree/master/po/cs) *
*  da - [Danish](https://salsa.debian.org/manpages-l10n-team/manpages-l10n/-/tree/master/po/da)
*  de - [German](https://salsa.debian.org/manpages-l10n-team/manpages-l10n/-/tree/master/po/de)
*  el - [Greek](https://salsa.debian.org/manpages-l10n-team/manpages-l10n/-/tree/master/po/el) *
*  es - [Spanish](https://salsa.debian.org/manpages-l10n-team/manpages-l10n/-/tree/master/po/es)
*  fa - [Persian](https://salsa.debian.org/manpages-l10n-team/manpages-l10n/-/tree/master/po/fa)
*  fi - [Finnish](https://salsa.debian.org/manpages-l10n-team/manpages-l10n/-/tree/master/po/fi) *
*  fr - [French](https://salsa.debian.org/manpages-l10n-team/manpages-l10n/-/tree/master/po/fr)
*  hu - [Hungarian](https://salsa.debian.org/manpages-l10n-team/manpages-l10n/-/tree/master/po/hu) *
*  id - [Indonesian](https://salsa.debian.org/manpages-l10n-team/manpages-l10n/-/tree/master/po/id)
*  it - [Italian](https://salsa.debian.org/manpages-l10n-team/manpages-l10n/-/tree/master/po/it)
*  mk - [Macedonian](https://salsa.debian.org/manpages-l10n-team/manpages-l10n/-/tree/master/po/mk) *
*  nb - [Norwegian bokmål](https://salsa.debian.org/manpages-l10n-team/manpages-l10n/-/tree/master/po/nb) *
*  nl - [Dutch](https://salsa.debian.org/manpages-l10n-team/manpages-l10n/-/tree/master/po/nl)
*  pl - [Polish](https://salsa.debian.org/manpages-l10n-team/manpages-l10n/-/tree/master/po/pl)
*  pt_BR - [Brazilian Portuguese](https://salsa.debian.org/manpages-l10n-team/manpages-l10n/-/tree/master/po/pt_BR)
*  ro - [Romanian](https://salsa.debian.org/manpages-l10n-team/manpages-l10n/-/tree/master/po/ro) *
*  sr - [Serbian](https://salsa.debian.org/manpages-l10n-team/manpages-l10n/-/tree/master/po/sr) *
*  sv - [Swedish](https://salsa.debian.org/manpages-l10n-team/manpages-l10n/-/tree/master/po/sv) *
*  uk - [Ukrainian](https://salsa.debian.org/manpages-l10n-team/manpages-l10n/-/tree/master/po/uk)
*  vi - [Vietnamese](https://salsa.debian.org/manpages-l10n-team/manpages-l10n/-/tree/master/po/vi) *

(the languages marked with * are currently - at least partially - unmaintained,
feel free to pick up the maintenance)

The project is open for adding more languages. For inclusion of a new one,
please contact [Mario Blättermann](mailto:mario.blaettermann@gmail.com).

The current status is available [here](https://manpages-l10n-team.pages.debian.net/manpages-l10n/).

The git repository and further informations are available [here](https://salsa.debian.org/manpages-l10n-team/manpages-l10n).

==> manpages-l10n_4.18.1.orig.tar.gz: manpages-l10n-4.18.1/README.md <==
# manpages-l10n

This project provides an infrastructure for translating manpages to different
languages. Currently we support the following languages:

*  cs - [Czech](https://salsa.debian.org/manpages-l10n-team/manpages-l10n/-/tree/master/po/cs) *
*  da - [Danish](https://salsa.debian.org/manpages-l10n-team/manpages-l10n/-/tree/master/po/da)
*  de - [German](https://salsa.debian.org/manpages-l10n-team/manpages-l10n/-/tree/master/po/de)
*  el - [Greek](https://salsa.debian.org/manpages-l10n-team/manpages-l10n/-/tree/master/po/el) *
*  es - [Spanish](https://salsa.debian.org/manpages-l10n-team/manpages-l10n/-/tree/master/po/es)
*  fa - [Persian](https://salsa.debian.org/manpages-l10n-team/manpages-l10n/-/tree/master/po/fa)
*  fi - [Finnish](https://salsa.debian.org/manpages-l10n-team/manpages-l10n/-/tree/master/po/fi) *
*  fr - [French](https://salsa.debian.org/manpages-l10n-team/manpages-l10n/-/tree/master/po/fr)
*  hu - [Hungarian](https://salsa.debian.org/manpages-l10n-team/manpages-l10n/-/tree/master/po/hu) *
*  id - [Indonesian](https://salsa.debian.org/manpages-l10n-team/manpages-l10n/-/tree/master/po/id)
*  it - [Italian](https://salsa.debian.org/manpages-l10n-team/manpages-l10n/-/tree/master/po/it)
*  mk - [Macedonian](https://salsa.debian.org/manpages-l10n-team/manpages-l10n/-/tree/master/po/mk) *
*  nb - [Norwegian bokmål](https://salsa.debian.org/manpages-l10n-team/manpages-l10n/-/tree/master/po/nb) *
*  nl - [Dutch](https://salsa.debian.org/manpages-l10n-team/manpages-l10n/-/tree/master/po/nl)
*  pl - [Polish](https://salsa.debian.org/manpages-l10n-team/manpages-l10n/-/tree/master/po/pl)
*  pt_BR - [Brazilian Portuguese](https://salsa.debian.org/manpages-l10n-team/manpages-l10n/-/tree/master/po/pt_BR)
*  ro - [Romanian](https://salsa.debian.org/manpages-l10n-team/manpages-l10n/-/tree/master/po/ro) *
*  ro - [Russian](https://salsa.debian.org/manpages-l10n-team/manpages-l10n/-/tree/master/po/ru) *
*  sr - [Serbian](https://salsa.debian.org/manpages-l10n-team/manpages-l10n/-/tree/master/po/sr) *
*  sv - [Swedish](https://salsa.debian.org/manpages-l10n-team/manpages-l10n/-/tree/master/po/sv)
*  uk - [Ukrainian](https://salsa.debian.org/manpages-l10n-team/manpages-l10n/-/tree/master/po/uk)
*  vi - [Vietnamese](https://salsa.debian.org/manpages-l10n-team/manpages-l10n/-/tree/master/po/vi) *

(the languages marked with * are currently - at least partially - unmaintained,
feel free to pick up the maintenance)

The project is open for adding more languages. For inclusion of a new one,
please contact [Mario Blättermann](mailto:mario.blaettermann@gmail.com).

The current status is available [here](https://manpages-l10n-team.pages.debian.net/manpages-l10n/).

The git repository and further informations are available [here](https://salsa.debian.org/manpages-l10n-team/manpages-l10n).
